==> ShapeView-6.2-sources.jar: com/hjq/shape/styleable/ShapeViewStyleable.java <==
package com.hjq.shape.styleable;

import com.hjq.shape.R;

/**
 *    author : Android 轮子哥
 *    github : https://github.com/getActivity/ShapeView
 *    time   : 2021/08/28
 *    desc   : View 的 Shape 属性值
 */
public final class ShapeViewStyleable implements IShapeDrawableStyleable {

    /**
     * {@link IShapeDrawableStyleable}
     */

    @Override
    public int getShapeTypeStyleable() {
        return R.styleable.ShapeView_shape;
    }

    @Override
    public int getShapeWidthStyleable() {
        return R.styleable.ShapeView_shape_width;
    }

    @Override
    public int getShapeHeightStyleable() {
        return R.styleable.ShapeView_shape_height;
    }

    @Override
    public int getSolidColorStyleable() {
        return R.styleable.ShapeView_shape_solidColor;
    }

    @Override
    public int getSolidPressedColorStyleable() {
        return R.styleable.ShapeView_shape_solidPressedColor;
    }

    @Override
    public int getSolidDisabledColorStyleable() {
        return R.styleable.ShapeView_shape_solidDisabledColor;
    }

    @Override
    public int getSolidFocusedColorStyleable() {
        return R.styleable.ShapeView_shape_solidFocusedColor;
    }

    @Override
    public int getSolidSelectedColorStyleable() {
        return R.styleable.ShapeView_shape_solidSelectedColor;
    }

    @Override
    public int getRadiusStyleable() {
        return R.styleable.ShapeView_shape_radius;
    }

    @Override
    public int getTopLeftRadiusStyleable() {
        return R.styleable.ShapeView_shape_topLeftRadius;
    }

    @Override
    public int getTopRightRadiusStyleable() {
        return R.styleable.ShapeView_shape_topRightRadius;
    }

    @Override
    public int getBottomLeftRadiusStyleable() {
        return R.styleable.ShapeView_shape_bottomLeftRadius;
    }

    @Override
    public int getBottomRightRadiusStyleable() {
        return R.styleable.ShapeView_shape_bottomRightRadius;
    }

    @Override
    public int getStartColorStyleable() {
        return R.styleable.ShapeView_shape_startColor;
    }

    @Override
    public int getCenterColorStyleable() {
        return R.styleable.ShapeView_shape_centerColor;
    }

    @Override
    public int getEndColorStyleable() {
        return R.styleable.ShapeView_shape_endColor;
    }

    @Override
    public int getUseLevelStyleable() {
        return R.styleable.ShapeView_shape_useLevel;
    }

    @Override
    public int getAngleStyleable() {
        return R.styleable.ShapeView_shape_angle;
    }

    @Override
    public int getGradientTypeStyleable() {
        return R.styleable.ShapeView_shape_gradientType;
    }

    @Override
    public int getCenterXStyleable() {
        return R.styleable.ShapeView_shape_centerX;
    }

    @Override
    public int getCenterYStyleable() {
        return R.styleable.ShapeView_shape_centerY;
    }

    @Override
    public int getGradientRadiusStyleable() {
        return R.styleable.ShapeView_shape_gradientRadius;
    }

    @Override
    public int getStrokeColorStyleable() {
        return R.styleable.ShapeView_shape_strokeColor;
    }

    @Override
    public int getStrokePressedColorStyleable() {
        return R.styleable.ShapeView_shape_strokePressedColor;
    }

    @Override
    public int getStrokeDisabledColorStyleable() {
        return R.styleable.ShapeView_shape_strokeDisabledColor;
    }

    @Override
    public int getStrokeFocusedColorStyleable() {
        return R.styleable.ShapeView_shape_strokeFocusedColor;
    }

    @Override
    public int getStrokeSelectedColorStyleable() {
        return R.styleable.ShapeView_shape_strokeSelectedColor;
    }

    @Override
    public int getStrokeWidthStyleable() {
        return R.styleable.ShapeView_shape_strokeWidth;
    }

    @Override
    public int getDashWidthStyleable() {
        return R.styleable.ShapeView_shape_dashWidth;
    }

    @Override
    public int getDashGapStyleable() {
        return R.styleable.ShapeView_shape_dashGap;
    }

    @Override
    public int getInnerRadiusStyleable() {
        return R.styleable.ShapeView_shape_innerRadius;
    }

    @Override
    public int getInnerRadiusRatioStyleable() {
        return R.styleable.ShapeView_shape_innerRadiusRatio;
    }

    @Override
    public int getThicknessStyleable() {
        return R.styleable.ShapeView_shape_thickness;
    }

    @Override
    public int getThicknessRatioStyleable() {
        return R.styleable.ShapeView_shape_thicknessRatio;
    }

    @Override
    public int getShadowSizeStyleable() {
        return R.styleable.ShapeView_shape_shadowSize;
    }

    @Override
    public int getShadowColorStyleable() {
        return R.styleable.ShapeView_shape_shadowColor;
    }

    @Override
    public int getShadowOffsetXStyleable() {
        return R.styleable.ShapeView_shape_shadowOffsetX;
    }

    @Override
    public int getShadowOffsetYStyleable() {
        return R.styleable.ShapeView_shape_shadowOffsetY;
    }
}

==> ShapeView-8.0-sources.jar: com/hjq/shape/styleable/ShapeViewStyleable.java <==
package com.hjq.shape.styleable;

import com.hjq.shape.R;

/**
 *    author : Android 轮子哥
 *    github : https://github.com/getActivity/ShapeView
 *    time   : 2021/08/28
 *    desc   : View 的 Shape 属性值
 */
public final class ShapeViewStyleable implements IShapeDrawableStyleable {

    /**
     * {@link IShapeDrawableStyleable}
     */

    @Override
    public int getShapeTypeStyleable() {
        return R.styleable.ShapeView_shape;
    }

    @Override
    public int getShapeWidthStyleable() {
        return R.styleable.ShapeView_shape_width;
    }

    @Override
    public int getShapeHeightStyleable() {
        return R.styleable.ShapeView_shape_height;
    }

    @Override
    public int getSolidColorStyleable() {
        return R.styleable.ShapeView_shape_solidColor;
    }

    @Override
    public int getSolidPressedColorStyleable() {
        return R.styleable.ShapeView_shape_solidPressedColor;
    }

    @Override
    public int getSolidDisabledColorStyleable() {
        return R.styleable.ShapeView_shape_solidDisabledColor;
    }

    @Override
    public int getSolidFocusedColorStyleable() {
        return R.styleable.ShapeView_shape_solidFocusedColor;
    }

    @Override
    public int getSolidSelectedColorStyleable() {
        return R.styleable.ShapeView_shape_solidSelectedColor;
    }

    @Override
    public int getRadiusStyleable() {
        return R.styleable.ShapeView_shape_radius;
    }

    @Override
    public int getTopLeftRadiusStyleable() {
        return R.styleable.ShapeView_shape_topLeftRadius;
    }

    @Override
    public int getTopRightRadiusStyleable() {
        return R.styleable.ShapeView_shape_topRightRadius;
    }

    @Override
    public int getBottomLeftRadiusStyleable() {
        return R.styleable.ShapeView_shape_bottomLeftRadius;
    }

    @Override
    public int getBottomRightRadiusStyleable() {
        return R.styleable.ShapeView_shape_bottomRightRadius;
    }

    @Override
    public int getSolidStartColorStyleable() {
        return R.styleable.ShapeView_shape_startColor;
    }

    @Override
    public int getSolidCenterColorStyleable() {
        return R.styleable.ShapeView_shape_centerColor;
    }

    @Override
    public int getSolidEndColorStyleable() {
        return R.styleable.ShapeView_shape_endColor;
    }

    @Override
    public int getStrokeStartColorStyleable() {
        return R.styleable.ShapeView_shape_strokeStartColor;
    }

    @Override
    public int getStrokeCenterColorStyleable() {
        return R.styleable.ShapeView_shape_strokeCenterColor;
    }

    @Override
    public int getStrokeEndColorStyleable() {
        return R.styleable.ShapeView_shape_strokeEndColor;
    }

    @Override
    public int getUseLevelStyleable() {
        return R.styleable.ShapeView_shape_useLevel;
    }

    @Override
    public int getAngleStyleable() {
        return R.styleable.ShapeView_shape_angle;
    }

    @Override
    public int getGradientTypeStyleable() {
        return R.styleable.ShapeView_shape_gradientType;
    }

    @Override
    public int getCenterXStyleable() {
        return R.styleable.ShapeView_shape_centerX;
    }

    @Override
    public int getCenterYStyleable() {
        return R.styleable.ShapeView_shape_centerY;
    }

    @Override
    public int getGradientRadiusStyleable() {
        return R.styleable.ShapeView_shape_gradientRadius;
    }

    @Override
    public int getStrokeColorStyleable() {
        return R.styleable.ShapeView_shape_strokeColor;
    }

    @Override
    public int getStrokePressedColorStyleable() {
        return R.styleable.ShapeView_shape_strokePressedColor;
    }

    @Override
    public int getStrokeDisabledColorStyleable() {
        return R.styleable.ShapeView_shape_strokeDisabledColor;
    }

    @Override
    public int getStrokeFocusedColorStyleable() {
        return R.styleable.ShapeView_shape_strokeFocusedColor;
    }

    @Override
    public int getStrokeSelectedColorStyleable() {
        return R.styleable.ShapeView_shape_strokeSelectedColor;
    }

    @Override
    public int getStrokeWidthStyleable() {
        return R.styleable.ShapeView_shape_strokeWidth;
    }

    @Override
    public int getDashWidthStyleable() {
        return R.styleable.ShapeView_shape_dashWidth;
    }

    @Override
    public int getDashGapStyleable() {
        return R.styleable.ShapeView_shape_dashGap;
    }

    @Override
    public int getInnerRadiusStyleable() {
        return R.styleable.ShapeView_shape_innerRadius;
    }

    @Override
    public int getInnerRadiusRatioStyleable() {
        return R.styleable.ShapeView_shape_innerRadiusRatio;
    }

    @Override
    public int getThicknessStyleable() {
        return R.styleable.ShapeView_shape_thickness;
    }

    @Override
    public int getThicknessRatioStyleable() {
        return R.styleable.ShapeView_shape_thicknessRatio;
    }

    @Override
    public int getShadowSizeStyleable() {
        return R.styleable.ShapeView_shape_shadowSize;
    }

    @Override
    public int getShadowColorStyleable() {
        return R.styleable.ShapeView_shape_shadowColor;
    }

    @Override
    public int getShadowOffsetXStyleable() {
        return R.styleable.ShapeView_shape_shadowOffsetX;
    }

    @Override
    public int getShadowOffsetYStyleable() {
        return R.styleable.ShapeView_shape_shadowOffsetY;
    }
}
